Skip to contents

A square numeric matrix representing interaction coefficients between species. a_ij is the per-capita interaction strength of species j on species i. It expresses the change in carrying capacity of species i by a single individual of species j. This data is compatible with n1_map_eg.tif and K_map_eg.tif maps.

Usage

a_eg

Format

A numeric matrix with 4 rows and 4 columns containing interaction coefficients.

Data generated in-house to serve as an example