Skip to contents

A pre-initialized sim_com_data object used to demonstrate community structure and simulation input. It contains 4 species with spatially correlated carrying capacity and initial abundance maps.

This object can be accessed via the get_community function.

Format

An object of class sim_com_data from the mrangr package generated using initialise_com.

Data generated in-house to serve as an example