Learn R Programming

mrangr (version 1.0.1)

a_eg: Example Of Interaction Coefficients Matrix

Description

A square numeric matrix representing interaction coefficients between species. a_ij is the per-capita interaction strength of species j on species i. It expresses the change in carrying capacity of species i by a single individual of species j. This data is compatible with n1_map_eg.tif and K_map_eg.tif maps.

Usage

a_eg

Arguments

Format

A numeric matrix with 4 rows and 4 columns containing interaction coefficients.