Learn R Programming

mrangr (version 1.0.1)

community_eg: Example Community Data

Description

A pre-initialized sim_com_data object used to demonstrate community structure and simulation input. It contains 4 species with spatially correlated carrying capacity and initial abundance maps.

This object can be accessed via the get_community function.

Arguments

Format

An object of class sim_com_data from the mrangr package generated using initialise_com.

See Also

get_community, initialise_com